@@ -1,6 +1,7 @@
 // Copyright (C) 2017 Witekio.
 // Copyright (C) 2018 The Qt Company Ltd.
 // SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0-only
+// Qt-Security score:significant reason:default
 
 #include "qcoapclient_p.h"
 #include "qcoapprotocol_p.h"
@@ -258,7 +259,8 @@ QCoapReply *QCoapClient::put(const QCoapRequest &request, const QByteArray &data
 
     Sends the \a request using the PUT method and returns a new QCoapReply
     object. Uses \a device content as the payload for this request.
-    A null device is treated as empty content.
+    A null device is treated as empty content, in which case the payload of the
+    \a request will be used.
 
     \note The device has to be open and readable before calling this function.
 
@@ -305,7 +307,8 @@ QCoapReply *QCoapClient::post(const QCoapRequest &request, const QByteArray &dat
 
     Sends the \a request using the POST method and returns a new QCoapReply
     object. Uses \a device content as the payload for this request.
-    A null device is treated as empty content.
+    A null device is treated as empty content, in which case the payload of the
+    \a request will be used.
 
     \note The device has to be open and readable before calling this function.
 
@@ -313,10 +316,7 @@ QCoapReply *QCoapClient::post(const QCoapRequest &request, const QByteArray &dat
 */
 QCoapReply *QCoapClient::post(const QCoapRequest &request, QIODevice *device)
 {
-    if (!device)
-        return nullptr;
-
-    return post(request, device->readAll());
+    return post(request, device ? device->readAll() : QByteArray());
 }
 
 /*!
@@ -444,7 +444,7 @@ QCoapReply *QCoapClient::observe(const QCoapRequest &request)
                                                                   d->connection->isSecure());
     copyRequest.enableObserve();
 
-    return get(copyRequest);
+    return d->sendRequest(copyRequest);
 }
 
 /*!
